@@ -53,6 +53,7 @@ class ROC:
     enable: bool = True
     add_template: bool = False
     remove_template: bool = False
+    download_templates: bool = False 
     delete_existing: bool = False
     base_galaxies: List = field(default_factory=lambda: [
                                      'M_83', 'Circinus', 'NGC_5023', 'NGC_2903', 'NGC_3198', 'NGC_5204', 'UGC_1281', 'UGC_7774', 'ESO_223_G009'])
@@ -77,7 +78,7 @@ class General:
     tirific: str = "tirific"  # Command to call tirific
     sofia2: str = "sofia2"  # Command to call sofia 2
     multiprocessing: bool = True
-
+    font_file: str = "/usr/share/fonts/truetype/msttcorefonts/Times_New_Roman.ttf"
 
 @dataclass
 class Config:
